==> ember-0.4.2.tar.bz2: ember-0.4.2/src/components/ogre/model/mapping/IActionCreator.h <==
//
// C++ Interface: IActionCreator
//
// Description: 
//
//
// Author: Erik Hjortsberg <erik@katastrof.nu>, (C) 2007
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.//
//
#include "Definitions/CaseDefinition.h"

namespace EmberOgre {

namespace Model {

namespace Mapping {

namespace Cases {
class CaseBase;
}

class ModelMapping;

/**
Interface that allows for client specific actions to be created.

Clients that use the Mapping framework are required to implement this interface. This interface is used in ModelMappingManager::createMapping(...)
*/
class IActionCreator
{
public:
	~IActionCreator() {}
	
	/**
	Creates actions for the supplied case.
	Use Cases::CaseBase::addAction(...) to add the actions to the case.
	*/
	virtual void createActions(ModelMapping& modelMapping, Cases::CaseBase* aCase, Definitions::CaseDefinition& caseDefinition) = 0;
private:
};

}

}

}

==> ember-0.5.0.tar.bz2: ember-0.5.0/src/components/ogre/model/mapping/IActionCreator.h <==
//
// C++ Interface: IActionCreator
//
// Description: 
//
//
// Author: Erik Hjortsberg <erik@katastrof.nu>, (C) 2007
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.//
//
#include "Definitions/CaseDefinition.h"

namespace EmberOgre {

namespace Model {

namespace Mapping {

namespace Cases {
class CaseBase;
}

class ModelMapping;

/**
Interface that allows for client specific actions to be created.

Clients that use the Mapping framework are required to implement this interface. This interface is used in ModelMappingManager::createMapping(...)
*/
class IActionCreator
{
public:
	virtual ~IActionCreator() {}
	
	/**
	Creates actions for the supplied case.
	Use Cases::CaseBase::addAction(...) to add the actions to the case.
	*/
	virtual void createActions(ModelMapping& modelMapping, Cases::CaseBase* aCase, Definitions::CaseDefinition& caseDefinition) = 0;
private:
};

}

}

}
